@@ -6,7 +6,7 @@ use warnings;
 use experimental 'smartmatch';
 
 our $DATE = '2014-07-09'; # DATE
-our $VERSION = '0.72'; # VERSION
+our $VERSION = '0.73'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -70,9 +70,13 @@ sub parse_getopt_long_opt_spec {
     delete $res{name};
     delete $res{aliases};
 
+    $res{is_neg} = 1 if $res{is_neg};
+    $res{is_inc} = 1 if $res{is_inc};
+
     $res{normalized} = join(
         "",
         join("|", sort @{ $res{opts} }),
+        ($res{is_neg} ? "!" : $res{is_inc} ? "+" : ""),
         ($res{type} ? ("=", $res{type}, $res{desttype},
                        (defined($res{max_vals}) ? (defined($res{min_vals}) ? "{$res{min_vals},$res{max_vals}}" : "{$res{max_vals}}") : ())) : ()),
         ($res{opttype} ? (":", $res{opttype}, $res{desttype}) : ()),
@@ -124,7 +128,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.72 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2014-07-09.
+This document describes version 0.73 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2014-07-09.
 
 =head1 FUNCTIONS
 
